﻿using System;
using Microsoft.Practices.Composite.Modularity;
using Microsoft.Practices.Composite.Regions;
using Microsoft.Practices.Composite.Events;
using Microsoft.Practices.Unity;
using CompanyModule.Views;
using CompanyModule.ViewModels;
using CompanyModule.Events;

namespace CompanyModule
{
    public class CompanyModule : IModule
    {

        private readonly IRegionManager _regionManager;
        private IEventAggregator _eventAggregator;
        private IUnityContainer _unityContainer;

        public CompanyModule(IRegionManager regionManager, IEventAggregator eventAggregator, IUnityContainer unityContainer)
        {
            _regionManager = regionManager;
            _eventAggregator = eventAggregator;
            _unityContainer = unityContainer;
        }

        public void Initialize()
        {
            RegisterViewsAndServices();
            SubscribeToEvents();
            var view = _unityContainer.Resolve<CompanyListView>();
            var viewModel = _unityContainer.Resolve<CompanyListViewModel>();
            view.DataContext = viewModel;
            _regionManager.Regions["MainRegion"].Add(view, "ListView");
        }

        private void SubscribeToEvents()
        {
            _eventAggregator.GetEvent<EditCompanyEvent>().Subscribe((c) =>
                {
                    var view = _unityContainer.Resolve<EditCompanyView>();
                    var vm = _unityContainer.Resolve<IEditCompanyViewModel>();
                    vm.CurrentCompany = c.Company;
                    vm.Context = c.Context;
                    view.DataContext = vm;
                    _regionManager.Regions["MainRegion"].Add(view, "EditView");
                    _regionManager.Regions["MainRegion"].Activate(view);
                }, true);

            _eventAggregator.GetEvent<CloseCompanyEvent>().Subscribe((b) =>
                {
                    _regionManager.Regions["MainRegion"].Remove(_regionManager.Regions["MainRegion"].GetView("EditView"));
                    _regionManager.Regions["MainRegion"].Activate(_regionManager.Regions["MainRegion"].GetView("ListView"));
                }, true);
        }

        protected void RegisterViewsAndServices()
        {
            _unityContainer.RegisterType(typeof(CompanyListView), "CompanyListView");
            _unityContainer.RegisterType(typeof(ICompanyListViewModel),typeof(CompanyListViewModel));
            _unityContainer.RegisterType(typeof(EditCompanyView), "EditCompanyView");
            _unityContainer.RegisterType(typeof(IEditCompanyViewModel), typeof(EditCompanyViewModel));
        }
    }
}
