﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using SilverlightTestingDemo.Web;
using System.ComponentModel;
using System.Collections.Generic;
using System.ServiceModel.DomainServices.Client;
using Microsoft.Practices.Composite.Presentation.Commands;
using Microsoft.Practices.Composite.Events;
using CompanyModule.Events;
using System.Data.Services.Client;
using System.Collections.ObjectModel;

namespace CompanyModule.ViewModels
{
    public class CompanyListViewModel : INotifyPropertyChanged, ICompanyListViewModel
    {
        private IEventAggregator _eventAggregator;

        public CompanyListViewModel(IEventAggregator eventAggregator)
        {
            _eventAggregator = eventAggregator;
            GetCompaniesCommand = new DelegateCommand<object>(GetCompanies);
            DoubleClickCommad = new DelegateCommand<object>(SelectCompanyForEdit);
            _context = new CompanyDomainContext(new Uri(@"http://localhost:4988/SilverlightTestingDemo-Web-CompanyDomainService.svc", UriKind.Absolute));

        }
        private CompanyDomainContext _context;

        private void GetCompanies(object load)
        {
            IsBusy = true;
            EntityQuery<Company> query = _context.GetCompaniesQuery();
            query.OrderBy(one => one.CompanyName);

            _context.Load<Company>(query, (result) =>
                {
                    IsBusy = false;
                    if (result.Error == null)
                    {
                        CompanyList = new ObservableCollection<Company>(result.Entities);
                    }
                    else
                    {
                        MessageBox.Show(result.Error.ToString());
                    }

                }, null);
        }

        private void SelectCompanyForEdit(object load)
        {
            if (load != null && load is Company)
            {
                _eventAggregator.GetEvent<EditCompanyEvent>().Publish(new EditCompanyPayload(load as Company, _context));
            }
        }

        private bool _isBusy = false;
        public bool IsBusy
        {
            get
            {
                return _isBusy;
            }
            private set
            {
                _isBusy = value;
                OnPropertyCHanged("IsBusy");
            }
        }

        private ObservableCollection<Company> _companyList;
        public ObservableCollection<Company> CompanyList
        {
            get
            {
                return _companyList;
            }
            private set
            {
                _companyList = value;
                OnPropertyCHanged("CompanyList");
            }
        }

        public DelegateCommand<object> GetCompaniesCommand { get; private set; }
        public DelegateCommand<object> DoubleClickCommad { get; private set; }


        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyCHanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
